/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { NextResponse } from "next/server";
import { getCodebergIssues } from "../../../lib/codeberg";

/**
 * GET route handler for the activity API.
 * Loads recent activity from Codeberg and GitHub.
 * @returns The formatted data.
 */
export async function GET(): Promise<NextResponse> {
  const issues = await getCodebergIssues();
  const normalised = issues.map((issue) => {
    return {
      body:   issue.body,
      labels: issue.labels.map((label) => {
        return label.name;
      }),
      number: issue.number,
      title:  issue.title,
      url:    issue.html_url,
    };
  });
  return NextResponse.json(normalised);
}
