/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import type { JSX } from "react";

interface ActivityProperties {
  readonly type:     string;
  readonly date:     Date;
  readonly repo:     string;
  readonly repoName: string;
  readonly heart:    string;
}

const TypeToString: Record<string, string> = {
  DeleteEvent:                   "deleted a branch on",
  IssueCommentEvent:             "commented on",
  IssuesEvent:                   "created or updated an issue in",
  PullRequestEvent:              "created or merged a PR in",
  PullRequestReviewCommentEvent: "commented on a PR in",
  PullRequestReviewEvent:        "reviewed a PR in",
  PushEvent:                     "committed to",
  close_issue:                   "closed an issue in",
  commit_repo:                   "committed to",
  create_branch:                 "created a branch in",
  create_issue:                  "created an issue in",
  create_pull_request:           "created a PR in",
  delete_branch:                 "deleted a branch on",
  merge_pull_request:            "merged a PR in",
};

const getType = (type: string): string => {
  return TypeToString[type] ?? `performed a ${type}`;
};

/**
 * Renders the view for a Github or Codeberg activity.
 * @param properties - The activity to render.
 * @returns A JSX element.
 */
export const Activity = (properties: ActivityProperties): JSX.Element => {
  const { type, date, repo, repoName, heart } = properties;
  return (
    <li className="ms-6">
      <span
        className="absolute flex items-center
        justify-center w-6 h-6 rounded-full -start-3"
      >
        {heart}
      </span>
      <div
        className="items-center justify-between
      p-4 bg-white border border-gray-200 rounded-lg
      shadow-sm sm:flex dark:bg-gray-700 dark:border-gray-600"
      >
        <time
          className="mb-1 text-xs font-normal
        text-gray-400 sm:order-last sm:mb-0"
        >
          {date.toLocaleString("en-GB")}
        </time>
        <div
          className="text-sm font-normal
        text-gray-500 lex dark:text-gray-300"
        >
          {`Naomi has ${getType(type)} `}
          <a
            className="font-semibold text-[#abfcec] hover:underline"
            href={repo}
            rel="noopener noreferrer"
            target="_blank"
          >
            {repoName}
          </a>{" "}
        </div>
      </div>
    </li>
  );
};
